##  How to Implement Pace Layering in SAP LeanIX
Implementing pace layering in SAP LeanIX involves determining the classification of each business capability, documenting it, and using it for further assessment and planning of the enterprise architecture.
An outline of the process of implementing pace layering in SAP LeanIX is as follows:
  * Determine and document the pace layering classification of each business capability. Learn how in [Modeling Pace Layers](https://help.sap.com/docs/leanix/ea/modeling-pace-layers?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model the pace layering classification in SAP LeanIX.").
  * Use Reports and Diagrams to assess the application portfolio guided by your pace layering strategies. Learn more in [Application of Pace Layering in Assessments](https://help.sap.com/docs/leanix/ea/application-of-pace-layering-in-assessments?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to use pace layering to guide assessments.").
  * Finally, based on pace layering strategies, develop and implement the to-be-state architecture. Learn more in [Creating and Implementing a Future-State/To-Be-State Plan](https://help.sap.com/docs/leanix/ea/application-of-pace-layering-in-assessments?locale=en-US&state=PRODUCTION&version=CLOUD#loiod3a2dc1aa6e34570a924926e2bcbbf8f__creating_and_executing_future-state_to-be-state_plan).


You can complement pace with other methodologies like [TIME](https://help.sap.com/docs/leanix/ea/time?locale=en-US&state=PRODUCTION&version=CLOUD) and [6R](https://help.sap.com/docs/leanix/ea/6r?locale=en-US&state=PRODUCTION&version=CLOUD) within SAP LeanIX.
